You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by nt...@apache.org on 2015/11/04 16:22:13 UTC

ignite git commit: IGNITE-426 Fixed code style.

Repository: ignite
Updated Branches:
  refs/heads/ignite-462-2 7236c3a14 -> cd486cbe4


IGNITE-426 Fixed code style.


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/cd486cbe
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/cd486cbe
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/cd486cbe

Branch: refs/heads/ignite-462-2
Commit: cd486cbe4c31d844d2cd053e36dc0e18b6d52d94
Parents: 7236c3a
Author: nikolay_tikhonov <nt...@gridgain.com>
Authored: Wed Nov 4 18:22:14 2015 +0300
Committer: nikolay_tikhonov <nt...@gridgain.com>
Committed: Wed Nov 4 18:22:14 2015 +0300

----------------------------------------------------------------------
 .../internal/GridEventConsumeHandler.java       |  2 +-
 .../internal/GridMessageListenHandler.java      |  2 +-
 .../processors/cache/GridCacheEntryEx.java      |  8 +-
 .../processors/cache/GridCacheMapEntry.java     | 90 ++++++++++----------
 .../cache/GridCacheUpdateAtomicResult.java      | 14 ++-
 .../cache/GridCacheUpdateTxResult.java          | 10 +--
 .../GridDistributedTxRemoteAdapter.java         | 12 +--
 .../dht/GridClientPartitionTopology.java        |  2 +-
 .../distributed/dht/GridDhtLocalPartition.java  | 18 ++--
 .../dht/GridDhtPartitionTopologyImpl.java       |  6 +-
 .../distributed/dht/GridDhtTxFinishFuture.java  | 13 ++-
 .../dht/atomic/GridDhtAtomicCache.java          | 11 ++-
 .../dht/atomic/GridDhtAtomicUpdateFuture.java   |  2 +-
 .../distributed/near/GridNearTxRemote.java      |  4 +-
 .../CacheContinuousQueryBatchAck.java           | 20 ++---
 .../continuous/CacheContinuousQueryEntry.java   | 26 +++---
 .../continuous/CacheContinuousQueryHandler.java | 76 ++++++++---------
 .../CacheContinuousQueryListener.java           |  4 +-
 .../continuous/CacheContinuousQueryManager.java |  8 +-
 .../cache/transactions/IgniteTxEntry.java       | 10 +--
 .../cache/transactions/IgniteTxHandler.java     |  2 +-
 .../transactions/IgniteTxLocalAdapter.java      |  4 +-
 .../cache/transactions/IgniteTxRemoteEx.java    |  4 +-
 .../continuous/GridContinuousHandler.java       |  4 +-
 .../continuous/GridContinuousProcessor.java     | 20 ++---
 .../StartRoutineAckDiscoveryMessage.java        | 14 +--
 .../StartRoutineDiscoveryMessage.java           | 18 ++--
 .../processors/cache/GridCacheTestEntryEx.java  |  6 +-
 ...ContinuousQueryFailoverAbstractSelfTest.java |  1 -
 29 files changed, 202 insertions(+), 209 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/GridEventConsumeHandler.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/GridEventConsumeHandler.java b/modules/core/src/main/java/org/apache/ignite/internal/GridEventConsumeHandler.java
index fc65b55..3918976 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/GridEventConsumeHandler.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/GridEventConsumeHandler.java
@@ -130,7 +130,7 @@ class GridEventConsumeHandler implements GridContinuousHandler {
     }
 
     /** {@inheritDoc} */
-    @Override public void updateIdx(Map<Integer, Long> idx) {
+    @Override public void updateCounters(Map<Integer, Long> cntrs) {
         // No-op.
     }
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/GridMessageListenHandler.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/GridMessageListenHandler.java b/modules/core/src/main/java/org/apache/ignite/internal/GridMessageListenHandler.java
index 7711843..aa837b8 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/GridMessageListenHandler.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/GridMessageListenHandler.java
@@ -103,7 +103,7 @@ public class GridMessageListenHandler implements GridContinuousHandler {
     }
 
     /** {@inheritDoc} */
-    @Override public void updateIdx(Map<Integer, Long> idx) {
+    @Override public void updateCounters(Map<Integer, Long> cntrs) {
         // No-op.
     }
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheEntryEx.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheEntryEx.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheEntryEx.java
index aa6ea18..d1b6b29 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheEntryEx.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheEntryEx.java
@@ -360,6 +360,7 @@ public interface GridCacheEntryEx {
      * @param subjId Subject ID initiated this update.
      * @param taskName Task name.
      * @param dhtVer Dht version for near cache entry.
+     * @param updateCntr Update counter.
      * @return Tuple containing success flag and old value. If success is {@code false},
      *      then value is {@code null}.
      * @throws IgniteCheckedException If storing value failed.
@@ -383,7 +384,7 @@ public interface GridCacheEntryEx {
         @Nullable UUID subjId,
         String taskName,
         @Nullable GridCacheVersion dhtVer,
-        @Nullable Long updateIdx
+        @Nullable Long updateCntr
     ) throws IgniteCheckedException, GridCacheEntryRemovedException;
 
     /**
@@ -421,7 +422,7 @@ public interface GridCacheEntryEx {
         @Nullable UUID subjId,
         String taskName,
         @Nullable GridCacheVersion dhtVer,
-        @Nullable Long updatePartIdx
+        @Nullable Long updateCntr
     ) throws IgniteCheckedException, GridCacheEntryRemovedException;
 
     /**
@@ -450,6 +451,7 @@ public interface GridCacheEntryEx {
      * @param intercept If {@code true} then calls cache interceptor.
      * @param subjId Subject ID initiated this update.
      * @param taskName Task name.
+     * @param updateCntr Update counter.
      * @return Tuple where first value is flag showing whether operation succeeded,
      *      second value is old entry value if return value is requested, third is updated entry value,
      *      fourth is the version to enqueue for deferred delete the fifth is DR conflict context
@@ -484,7 +486,7 @@ public interface GridCacheEntryEx {
         @Nullable UUID subjId,
         String taskName,
         @Nullable CacheObject prevVal,
-        @Nullable Long updateIdx
+        @Nullable Long updateCntr
     ) throws IgniteCheckedException, GridCacheEntryRemovedException;
 
     /**

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheMapEntry.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheMapEntry.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheMapEntry.java
index 86051ed..561a8b2 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheMapEntry.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheMapEntry.java
@@ -33,7 +33,6 @@ import org.apache.ignite.IgniteLogger;
 import org.apache.ignite.cache.CacheAtomicWriteOrderMode;
 import org.apache.ignite.cache.CacheMemoryMode;
 import org.apache.ignite.cache.eviction.EvictableEntry;
-import org.apache.ignite.internal.IgniteInternalFuture;
 import org.apache.ignite.internal.managers.deployment.GridDeploymentInfo;
 import org.apache.ignite.internal.managers.deployment.GridDeploymentInfoBean;
 import org.apache.ignite.internal.processors.affinity.AffinityTopologyVersion;
@@ -62,7 +61,6 @@ import org.apache.ignite.internal.util.lang.GridTuple3;
 import org.apache.ignite.internal.util.offheap.unsafe.GridUnsafeMemory;
 import org.apache.ignite.internal.util.tostring.GridToStringExclude;
 import org.apache.ignite.internal.util.tostring.GridToStringInclude;
-import org.apache.ignite.internal.util.typedef.CI1;
 import org.apache.ignite.internal.util.typedef.F;
 import org.apache.ignite.internal.util.typedef.T2;
 import org.apache.ignite.internal.util.typedef.T3;
@@ -1063,7 +1061,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
         @Nullable UUID subjId,
         String taskName,
         @Nullable GridCacheVersion dhtVer,
-        @Nullable Long updateIdx
+        @Nullable Long updateCntr
     ) throws IgniteCheckedException, GridCacheEntryRemovedException {
         CacheObject old;
 
@@ -1080,7 +1078,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
         Object key0 = null;
         Object val0 = null;
 
-        long updateIdx0;
+        long updateCntr0;
 
         synchronized (this) {
             checkObsolete();
@@ -1159,10 +1157,10 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
                     deletedUnlocked(false);
             }
 
-            updateIdx0 = nextPartIndex(topVer);
+            updateCntr0 = nextPartCounter(topVer);
 
-            if (updateIdx != null && updateIdx != 0)
-                updateIdx0 = updateIdx;
+            if (updateCntr != null && updateCntr != 0)
+                updateCntr0 = updateCntr;
 
             update(val, expireTime, ttl, newVer);
 
@@ -1191,7 +1189,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
 
             if (cctx.isLocal() || cctx.isReplicated() ||
                 (!isNear() && !(tx != null && tx.onePhaseCommit() && !tx.local())))
-                cctx.continuousQueries().onEntryUpdated(this, key, val, old, tx.local(), false, updateIdx0, topVer);
+                cctx.continuousQueries().onEntryUpdated(this, key, val, old, tx.local(), false, updateCntr0, topVer);
 
             cctx.dataStructures().onEntryUpdated(key, false);
         }
@@ -1207,7 +1205,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
         if (intercept)
             cctx.config().getInterceptor().onAfterPut(new CacheLazyEntry(cctx, key, key0, val, val0));
 
-        return valid ? new GridCacheUpdateTxResult(true, retval ? old : null, updateIdx0) :
+        return valid ? new GridCacheUpdateTxResult(true, retval ? old : null, updateCntr0) :
             new GridCacheUpdateTxResult(false, null);
     }
 
@@ -1235,7 +1233,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
         @Nullable UUID subjId,
         String taskName,
         @Nullable GridCacheVersion dhtVer,
-        @Nullable Long updateIdx
+        @Nullable Long updateCntr
         ) throws IgniteCheckedException, GridCacheEntryRemovedException {
         assert cctx.transactional();
 
@@ -1257,7 +1255,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
 
         Cache.Entry entry0 = null;
 
-        Long updateIdx0;
+        Long updateCntr0;
 
         synchronized (this) {
             checkObsolete();
@@ -1328,10 +1326,10 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
                 }
             }
 
-            updateIdx0 = nextPartIndex(topVer);
+            updateCntr0 = nextPartCounter(topVer);
 
-            if (updateIdx != null && updateIdx != 0)
-                updateIdx0 = updateIdx;
+            if (updateCntr != null && updateCntr != 0)
+                updateCntr0 = updateCntr;
 
             drReplicate(drType, null, newVer);
 
@@ -1367,7 +1365,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
 
             if (cctx.isLocal() || cctx.isReplicated() ||
                 (!isNear() && !(tx != null && tx.onePhaseCommit() && !tx.local())))
-                cctx.continuousQueries().onEntryUpdated(this, key, null, old, tx.local(), false, updateIdx0, topVer);
+                cctx.continuousQueries().onEntryUpdated(this, key, null, old, tx.local(), false, updateCntr0, topVer);
 
             cctx.dataStructures().onEntryUpdated(key, true);
         }
@@ -1417,7 +1415,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
             else
                 ret = old;
 
-            return new GridCacheUpdateTxResult(true, ret, updateIdx0);
+            return new GridCacheUpdateTxResult(true, ret, updateCntr0);
         }
         else
             return new GridCacheUpdateTxResult(false, null);
@@ -1710,9 +1708,9 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
                 updateMetrics(op, metrics);
 
             if (!isNear()) {
-                long updateIdx = nextPartIndex(AffinityTopologyVersion.NONE);
+                long updateCntr = nextPartCounter(AffinityTopologyVersion.NONE);
 
-                cctx.continuousQueries().onEntryUpdated(this, key, val, old, true, false, updateIdx,
+                cctx.continuousQueries().onEntryUpdated(this, key, val, old, true, false, updateCntr,
                     AffinityTopologyVersion.NONE);
             }
 
@@ -1759,7 +1757,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
         @Nullable UUID subjId,
         String taskName,
         @Nullable CacheObject prevVal,
-        @Nullable Long updateIdx
+        @Nullable Long updateCntr
     ) throws IgniteCheckedException, GridCacheEntryRemovedException, GridClosureException {
         assert cctx.atomic();
 
@@ -1785,7 +1783,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
         Object key0 = null;
         Object updated0 = null;
 
-        Long updateIdx0 = null;
+        Long updateCntr0 = null;
 
         synchronized (this) {
             boolean needVal = intercept || retval || op == GridCacheOperation.TRANSFORM || !F.isEmptyOrNulls(filter);
@@ -1895,7 +1893,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
                             null,
                             null,
                             false,
-                            updateIdx0 == null ? 0 : updateIdx0);
+                            updateCntr0 == null ? 0 : updateCntr0);
                     }
                     // Will update something.
                     else {
@@ -1967,13 +1965,13 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
                             else
                                 evtVal = (CacheObject)writeObj;
 
-                            updateIdx0 = nextPartIndex(topVer);
+                            updateCntr0 = nextPartCounter(topVer);
 
-                            if (updateIdx != null)
-                                updateIdx0 = updateIdx;
+                            if (updateCntr != null)
+                                updateCntr0 = updateCntr;
 
                             cctx.continuousQueries().onEntryUpdated(GridCacheMapEntry.this, key, evtVal,
-                                    prevVal, primary, false, updateIdx0, topVer);
+                                    prevVal, primary, false, updateCntr0, topVer);
                         }
 
                         return new GridCacheUpdateAtomicResult(false,
@@ -1985,7 +1983,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
                             null,
                             null,
                             false,
-                            updateIdx0 == null ? 0 : updateIdx0);
+                            updateCntr0 == null ? 0 : updateCntr0);
                     }
                 }
                 else
@@ -2062,7 +2060,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
                         null,
                         null,
                         false,
-                        updateIdx0 == null ? 0 : updateIdx0);
+                        updateCntr0 == null ? 0 : updateCntr0);
                 }
             }
 
@@ -2110,7 +2108,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
                         null,
                         null,
                         false,
-                        updateIdx0 == null ? 0 : updateIdx);
+                        updateCntr0 == null ? 0 : updateCntr);
                 }
             }
             else
@@ -2211,7 +2209,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
                             null,
                             null,
                             false,
-                            updateIdx0 == null ? 0 : updateIdx0);
+                            updateCntr0 == null ? 0 : updateCntr0);
                     else if (interceptorVal != updated0) {
                         updated0 = cctx.unwrapTemporary(interceptorVal);
 
@@ -2248,10 +2246,10 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
 
                 update(updated, newExpireTime, newTtl, newVer);
 
-                updateIdx0 = nextPartIndex(topVer);
+                updateCntr0 = nextPartCounter(topVer);
 
-                if (updateIdx != null)
-                    updateIdx0 = updateIdx;
+                if (updateCntr != null)
+                    updateCntr0 = updateCntr;
 
                 drReplicate(drType, updated, newVer);
 
@@ -2293,7 +2291,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
                             null,
                             null,
                             false,
-                            updateIdx0 == null ? 0 : updateIdx0);
+                            updateCntr0 == null ? 0 : updateCntr0);
                 }
 
                 if (writeThrough)
@@ -2345,10 +2343,10 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
 
                 recordNodeId(affNodeId, topVer);
 
-                updateIdx0 = nextPartIndex(topVer);
+                updateCntr0 = nextPartCounter(topVer);
 
-                if (updateIdx != null)
-                    updateIdx0 = updateIdx;
+                if (updateCntr != null)
+                    updateCntr0 = updateCntr;
 
                 drReplicate(drType, null, newVer);
 
@@ -2404,7 +2402,7 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
             enqueueVer,
             conflictCtx,
             true,
-            updateIdx0);
+            updateCntr0);
     }
 
     /**
@@ -3223,15 +3221,15 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
                 else if (deletedUnlocked())
                     deletedUnlocked(false);
 
-                long updateIdx = 0;
+                long updateCntr = 0;
 
                 if (!preload)
-                    updateIdx = nextPartIndex(topVer);
+                    updateCntr = nextPartCounter(topVer);
 
                 drReplicate(drType, val, ver);
 
                 if (!skipQryNtf) {
-                    cctx.continuousQueries().onEntryUpdated(this, key, val, null, true, preload, updateIdx, topVer);
+                    cctx.continuousQueries().onEntryUpdated(this, key, val, null, true, preload, updateCntr, topVer);
 
                     cctx.dataStructures().onEntryUpdated(key, false);
                 }
@@ -3250,22 +3248,22 @@ public abstract class GridCacheMapEntry extends GridMetadataAwareAdapter impleme
 
     /**
      * @param topVer Topology version.
-     * @return Update index.
+     * @return Update counter.
      */
-    private long nextPartIndex(AffinityTopologyVersion topVer) {
-        long updateIdx;
+    private long nextPartCounter(AffinityTopologyVersion topVer) {
+        long updateCntr;
 
         if (!cctx.isLocal() && !isNear()) {
             GridDhtLocalPartition locPart = cctx.topology().localPartition(partition(), topVer, false);
 
             assert locPart != null;
 
-            updateIdx = locPart.nextUpdateIndex();
+            updateCntr = locPart.nextUpdateCounter();
         }
         else
-            updateIdx = 0;
+            updateCntr = 0;
 
-        return updateIdx;
+        return updateCntr;
     }
 
     /** {@inheritDoc} */

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheUpdateAtomicResult.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheUpdateTxResult.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheUpdateTxResult.java
index bea1000..461baa7 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheUpdateTxResult.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheUpdateTxResult.java
@@ -33,7 +33,7 @@ public class GridCacheUpdateTxResult {
     private final CacheObject oldVal;
 
     /** Partition idx. */
-    private long partIdx;
+    private long updateCntr;
 
     /**
      * Constructor.
@@ -52,17 +52,17 @@ public class GridCacheUpdateTxResult {
      * @param success Success flag.
      * @param oldVal Old value (if any),
      */
-    GridCacheUpdateTxResult(boolean success, @Nullable CacheObject oldVal, long partIdx) {
+    GridCacheUpdateTxResult(boolean success, @Nullable CacheObject oldVal, long updateCntr) {
         this.success = success;
         this.oldVal = oldVal;
-        this.partIdx = partIdx;
+        this.updateCntr = updateCntr;
     }
 
     /**
      * @return Partition idx.
      */
-    public long partIdx() {
-        return partIdx;
+    public long updatePartitionCounter() {
+        return updateCntr;
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/GridDistributedTxRemoteAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/GridDistributedTxRemoteAdapter.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/GridDistributedTxRemoteAdapter.java
index c972f43..af5ff12 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/GridDistributedTxRemoteAdapter.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/GridDistributedTxRemoteAdapter.java
@@ -282,12 +282,12 @@ public class GridDistributedTxRemoteAdapter extends IgniteTxAdapter
     }
 
     /** {@inheritDoc} */
-    @Override public void setPartitionUpdateIdx(long[] idxs) {
-        if (writeMap != null && !writeMap.isEmpty() && idxs != null && idxs.length > 0) {
+    @Override public void setPartitionUpdateCounters(long[] cntrs) {
+        if (writeMap != null && !writeMap.isEmpty() && cntrs != null && cntrs.length > 0) {
             int i = 0;
 
             for (IgniteTxEntry txEntry : writeMap.values()) {
-                txEntry.partIdx(idxs[i]);
+                txEntry.updateCounter(cntrs[i]);
 
                 ++i;
             }
@@ -605,7 +605,7 @@ public class GridDistributedTxRemoteAdapter extends IgniteTxAdapter
                                                 near() ? null : explicitVer, CU.subjectId(this, cctx),
                                                 resolveTaskName(),
                                                 dhtVer,
-                                                txEntry.partIdx());
+                                                txEntry.updateCounter());
                                         else {
                                             cached.innerSet(this,
                                                 eventNodeId(),
@@ -624,7 +624,7 @@ public class GridDistributedTxRemoteAdapter extends IgniteTxAdapter
                                                 CU.subjectId(this, cctx),
                                                 resolveTaskName(),
                                                 dhtVer,
-                                                txEntry.partIdx());
+                                                txEntry.updateCounter());
 
                                             // Keep near entry up to date.
                                             if (nearCached != null) {
@@ -654,7 +654,7 @@ public class GridDistributedTxRemoteAdapter extends IgniteTxAdapter
                                             CU.subjectId(this, cctx),
                                             resolveTaskName(),
                                             dhtVer,
-                                            txEntry.partIdx());
+                                            txEntry.updateCounter());
 
                                         // Keep near entry up to date.
                                         if (nearCached != null)

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridClientPartitionTopology.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridClientPartitionTopology.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridClientPartitionTopology.java
index 217073a..b7169bf 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridClientPartitionTopology.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridClientPartitionTopology.java
@@ -94,7 +94,7 @@ public class GridClientPartitionTopology implements GridDhtPartitionTopology {
     /** Lock. */
     private final ReentrantReadWriteLock lock = new ReentrantReadWriteLock();
 
-    /** Partition update counter. */
+    /** Partition update counters. */
     private Map<Integer, Long> cntrMap = new HashMap<>();
 
     /**

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtLocalPartition.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtLocalPartition.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtLocalPartition.java
index 1dc68cb..7b81989 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtLocalPartition.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtLocalPartition.java
@@ -117,8 +117,8 @@ public class GridDhtLocalPartition implements Comparable<GridDhtLocalPartition>,
     /** Group reservations. */
     private final CopyOnWriteArrayList<GridDhtPartitionsReservation> reservations = new CopyOnWriteArrayList<>();
 
-    /** Update index. */
-    private final AtomicLong updIdx = new AtomicLong();
+    /** Update counter. */
+    private final AtomicLong cntr = new AtomicLong();
 
     /**
      * @param cctx Context.
@@ -620,28 +620,28 @@ public class GridDhtLocalPartition implements Comparable<GridDhtLocalPartition>,
     /**
      * @return Next update index.
      */
-    public long nextUpdateIndex() {
-        return updIdx.incrementAndGet();
+    public long nextUpdateCounter() {
+        return cntr.incrementAndGet();
     }
 
     /**
      * @return Current update index.
      */
-    public long updateIndex() {
-        return updIdx.get();
+    public long updateCounter() {
+        return cntr.get();
     }
 
     /**
      * @param val Update index value.
      */
-    public void updateIndex(long val) {
+    public void updateCounter(long val) {
         while (true) {
-            long val0 = updIdx.get();
+            long val0 = cntr.get();
 
             if (val0 >= val)
                 break;
 
-            if (updIdx.compareAndSet(val0, val))
+            if (cntr.compareAndSet(val0, val))
                 break;
         }
     }

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtPartitionTopologyImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtPartitionTopologyImpl.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtPartitionTopologyImpl.java
index 5186589..6d64bd2 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtPartitionTopologyImpl.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtPartitionTopologyImpl.java
@@ -941,7 +941,7 @@ class GridDhtPartitionTopologyImpl implements GridDhtPartitionTopology {
                     Long cntr = cntrMap.get(part.id());
 
                     if (cntr != null)
-                        part.updateIndex(cntr);
+                        part.updateCounter(cntr);
                 }
             }
 
@@ -1054,7 +1054,7 @@ class GridDhtPartitionTopologyImpl implements GridDhtPartitionTopology {
                     Long cntr = cntrMap.get(part.id());
 
                     if (cntr != null)
-                        part.updateIndex(cntr);
+                        part.updateCounter(cntr);
                 }
             }
 
@@ -1316,7 +1316,7 @@ class GridDhtPartitionTopologyImpl implements GridDhtPartitionTopology {
 
             for (GridDhtLocalPartition part : locParts.values()) {
                 Long cntr0 = res.get(part.id());
-                Long cntr1 = part.updateIndex();
+                Long cntr1 = part.updateCounter();
 
                 if (cntr0 == null || cntr1 > cntr0)
                     res.put(part.id(), cntr1);

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtTxFinishFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtTxFinishFuture.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtTxFinishFuture.java
index 96459ab..1342b44 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtTxFinishFuture.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/GridDhtTxFinishFuture.java
@@ -17,9 +17,9 @@
 
 package org.apache.ignite.internal.processors.cache.distributed.dht;
 
+import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Map;
-import java.util.Set;
 import java.util.UUID;
 import java.util.concurrent.atomic.AtomicReference;
 import org.apache.ignite.IgniteCheckedException;
@@ -377,13 +377,10 @@ public final class GridDhtTxFinishFuture<K, V> extends GridCompoundIdentityFutur
 
             add(fut); // Append new future.
 
-            Collection<Long> updateIdxs = F.transform(dhtMapping.entries(), new C1<IgniteTxEntry, Long>() {
-                @Override public Long apply(IgniteTxEntry entry) {
-                    assert entry != null;
+            Collection<Long> updCntrs = new ArrayList<>(dhtMapping.entries().size());
 
-                    return entry.partIdx();
-                }
-            });
+            for (IgniteTxEntry e : dhtMapping.entries())
+                updCntrs.add(e.updateCounter());
 
             GridDhtTxFinishRequest req = new GridDhtTxFinishRequest(
                 tx.nearNodeId(),
@@ -409,7 +406,7 @@ public final class GridDhtTxFinishFuture<K, V> extends GridCompoundIdentityFutur
                 tx.subjectId(),
                 tx.taskNameHash(),
                 tx.activeCachesDeploymentEnabled(),
-                updateIdxs);
+                updCntrs);
 
             req.writeVersion(tx.writeVersion() != null ? tx.writeVersion() : tx.xidVersion());
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/atomic/GridDhtAtomicCache.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/atomic/GridDhtAtomicCache.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/atomic/GridDhtAtomicCache.java
index d44fc04..1ef1d1e 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/atomic/GridDhtAtomicCache.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/atomic/GridDhtAtomicCache.java
@@ -53,7 +53,6 @@ import org.apache.ignite.internal.processors.cache.GridCacheConcurrentMap;
 import org.apache.ignite.internal.processors.cache.GridCacheContext;
 import org.apache.ignite.internal.processors.cache.GridCacheEntryEx;
 import org.apache.ignite.internal.processors.cache.GridCacheEntryRemovedException;
-import org.apache.ignite.internal.processors.cache.GridCacheFilterFailedException;
 import org.apache.ignite.internal.processors.cache.GridCacheMapEntry;
 import org.apache.ignite.internal.processors.cache.GridCacheMapEntryFactory;
 import org.apache.ignite.internal.processors.cache.GridCacheOperation;
@@ -1765,7 +1764,7 @@ public class GridDhtAtomicCache<K, V> extends GridDhtCacheAdapter<K, V> {
                     filteredReaders = F.view(entry.readers(), F.notEqualTo(node.id()));
                 }
 
-                final GridCacheUpdateAtomicResult updRes = entry.innerUpdate(
+                GridCacheUpdateAtomicResult updRes = entry.innerUpdate(
                     ver,
                     node.id(),
                     locNodeId,
@@ -1819,7 +1818,7 @@ public class GridDhtAtomicCache<K, V> extends GridDhtCacheAdapter<K, V> {
                                 newConflictVer,
                                 sndPrevVal,
                                 updRes.oldValue(),
-                                updRes.updateIdx());
+                                updRes.updateCounter());
                         }
 
                         if (!F.isEmpty(filteredReaders))
@@ -1838,7 +1837,7 @@ public class GridDhtAtomicCache<K, V> extends GridDhtCacheAdapter<K, V> {
                 }
                 else if (!entry.isNear() && updRes.success()) {
                     ctx.continuousQueries().onEntryUpdated(entry, entry.key(), updRes.newValue(), updRes.oldValue(),
-                        primary, false, updRes.updateIdx(), topVer);
+                        primary, false, updRes.updateCounter(), topVer);
                 }
 
                 if (hasNear) {
@@ -2113,7 +2112,7 @@ public class GridDhtAtomicCache<K, V> extends GridDhtCacheAdapter<K, V> {
                                 null,
                                 sndPrevVal,
                                 updRes.oldValue(),
-                                updRes.updateIdx());
+                                updRes.updateCounter());
 
                         if (!F.isEmpty(filteredReaders))
                             dhtFut.addNearWriteEntries(filteredReaders,
@@ -2567,7 +2566,7 @@ public class GridDhtAtomicCache<K, V> extends GridDhtCacheAdapter<K, V> {
 
                         if (updRes.success() && !entry.isNear())
                             ctx.continuousQueries().onEntryUpdated(entry, entry.key(), updRes.newValue(),
-                                updRes.oldValue(), false, false, updRes.updateIdx(), req.topologyVersion());
+                                updRes.oldValue(), false, false, updRes.updateCounter(), req.topologyVersion());
 
                         entry.onUnlock();
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/atomic/GridDhtAtomicUpdateFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/atomic/GridDhtAtomicUpdateFuture.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/atomic/GridDhtAtomicUpdateFuture.java
index d73a018..ae0355b 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/atomic/GridDhtAtomicUpdateFuture.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/dht/atomic/GridDhtAtomicUpdateFuture.java
@@ -351,7 +351,7 @@ public class GridDhtAtomicUpdateFuture extends GridFutureAdapter<Void>
                             upd.get4(), updateRes.topologyVersion());
                     }
                     catch (IgniteCheckedException e) {
-                        log.warning("Failed to send continuous query message. [key=" + key + ", newVal="
+                        U.warn(log, "Failed to send continuous query message. [key=" + key + ", newVal="
                             + upd.get1() + ", err=" + e + "]");
                     }
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/near/GridNearTxRemote.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryBatchAck.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryBatchAck.java
index f89c466..3ad311f 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryBatchAck.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryBatchAck.java
@@ -38,10 +38,10 @@ public class CacheContinuousQueryBatchAck extends GridCacheMessage {
     /** Routine ID. */
     private UUID routineId;
 
-    /** Update indexes. */
+    /** Update counters. */
     @GridToStringInclude
     @GridDirectMap(keyType = Integer.class, valueType = Long.class)
-    private Map<Integer, Long> updateIdxs;
+    private Map<Integer, Long> updateCntrs;
 
     /**
      * Default constructor.
@@ -53,12 +53,12 @@ public class CacheContinuousQueryBatchAck extends GridCacheMessage {
     /**
      * @param cacheId Cache ID.
      * @param routineId Routine ID.
-     * @param updateIdxs Update indexes.
+     * @param updateCntrs Update counters.
      */
-    CacheContinuousQueryBatchAck(int cacheId, UUID routineId, Map<Integer, Long> updateIdxs) {
+    CacheContinuousQueryBatchAck(int cacheId, UUID routineId, Map<Integer, Long> updateCntrs) {
         this.cacheId = cacheId;
         this.routineId = routineId;
-        this.updateIdxs = updateIdxs;
+        this.updateCntrs = updateCntrs;
     }
 
     /**
@@ -69,10 +69,10 @@ public class CacheContinuousQueryBatchAck extends GridCacheMessage {
     }
 
     /**
-     * @return Update indexes.
+     * @return Update counters.
      */
-    Map<Integer, Long> updateIndexes() {
-        return updateIdxs;
+    Map<Integer, Long> updateCntrs() {
+        return updateCntrs;
     }
 
     /** {@inheritDoc} */
@@ -97,7 +97,7 @@ public class CacheContinuousQueryBatchAck extends GridCacheMessage {
                 writer.incrementState();
 
             case 4:
-                if (!writer.writeMap("updateIdxs", updateIdxs, MessageCollectionItemType.INT,
+                if (!writer.writeMap("updateCntrs", updateCntrs, MessageCollectionItemType.INT,
                     MessageCollectionItemType.LONG))
                     return false;
 
@@ -128,7 +128,7 @@ public class CacheContinuousQueryBatchAck extends GridCacheMessage {
                 reader.incrementState();
 
             case 4:
-                updateIdxs = reader.readMap("updateIdxs", MessageCollectionItemType.INT, MessageCollectionItemType.LONG,
+                updateCntrs = reader.readMap("updateCntrs", MessageCollectionItemType.INT, MessageCollectionItemType.LONG,
                     false);
 
                 if (!reader.isLastRead())

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryEntry.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryManager.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryManager.java
index a98f6a5..5f77c2e 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryManager.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryManager.java
@@ -119,7 +119,7 @@ public class CacheContinuousQueryManager extends GridCacheManagerAdapter {
                     CacheContinuousQueryListener lsnr = lsnrs.get(msg.routineId());
 
                     if (lsnr != null)
-                        lsnr.cleanupBackupQueue(msg.updateIndexes());
+                        lsnr.cleanupBackupQueue(msg.updateCntrs());
                 }
             });
 
@@ -164,7 +164,7 @@ public class CacheContinuousQueryManager extends GridCacheManagerAdapter {
      * @param oldVal Old value.
      * @param primary {@code True} if called on primary node.
      * @param preload Whether update happened during preloading.
-     * @param updateIdx Update index.
+     * @param updateCntr Update counter.
      * @param topVer Topology version.
      * @throws IgniteCheckedException In case of error.
      */
@@ -174,7 +174,7 @@ public class CacheContinuousQueryManager extends GridCacheManagerAdapter {
         CacheObject oldVal,
         boolean primary,
         boolean preload,
-        long updateIdx,
+        long updateCntr,
         AffinityTopologyVersion topVer)
         throws IgniteCheckedException
     {
@@ -233,7 +233,7 @@ public class CacheContinuousQueryManager extends GridCacheManagerAdapter {
                 newVal,
                 lsnr.oldValueRequired() ? oldVal : null,
                 e.partition(),
-                updateIdx,
+                updateCntr,
                 topVer);
 
             CacheContinuousQueryEvent evt = new CacheContinuousQueryEvent<>(

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxEntry.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxEntry.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxEntry.java
index 7d47b3b..65599fa 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxEntry.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxEntry.java
@@ -183,7 +183,7 @@ public class IgniteTxEntry implements GridPeerDeployAware, Message {
 
     /** Partition update index. */
     @GridDirectTransient
-    private long partIdx;
+    private long partUpdateCntr;
 
     /** */
     private GridCacheVersion serReadVer;
@@ -381,15 +381,15 @@ public class IgniteTxEntry implements GridPeerDeployAware, Message {
      *
      * @param partIdx Partition index.
      */
-    public void partIdx(long partIdx) {
-        this.partIdx = partIdx;
+    public void updateCounter(long partIdx) {
+        this.partUpdateCntr = partIdx;
     }
 
     /**
      * @return Partition index.
      */
-    public long partIdx() {
-        return partIdx;
+    public long updateCounter() {
+        return partUpdateCntr;
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxHandler.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxHandler.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxHandler.java
index 631f9f2..8855447 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxHandler.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxHandler.java
@@ -984,7 +984,7 @@ public class IgniteTxHandler {
                 // Complete remote candidates.
                 tx.doneRemote(req.baseVersion(), null, null, null);
 
-                tx.setPartitionUpdateIdx(
+                tx.setPartitionUpdateCounters(
                     req.partUpdateCounters() != null ? req.partUpdateCounters().array() : null);
 
                 tx.commit();

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxLocalAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxLocalAdapter.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxLocalAdapter.java
index 6f7ae27..d9a4097 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxLocalAdapter.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxLocalAdapter.java
@@ -1029,7 +1029,7 @@ public abstract class IgniteTxLocalAdapter extends IgniteTxAdapter
                                             null);
 
                                         if (updRes.success())
-                                            txEntry.partIdx(updRes.partIdx());
+                                            txEntry.updateCounter(updRes.updatePartitionCounter());
 
                                         if (nearCached != null && updRes.success()) {
                                             nearCached.innerSet(
@@ -1072,7 +1072,7 @@ public abstract class IgniteTxLocalAdapter extends IgniteTxAdapter
                                             null);
 
                                         if (updRes.success())
-                                            txEntry.partIdx(updRes.partIdx());
+                                            txEntry.updateCounter(updRes.updatePartitionCounter());
 
                                         if (nearCached != null && updRes.success()) {
                                             nearCached.innerRemove(

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxRemoteEx.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/GridContinuousProcessor.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/GridContinuousProcessor.java
index db9b714..4ff7325 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/GridContinuousProcessor.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/GridContinuousProcessor.java
@@ -212,30 +212,29 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
 
                             if (routine != null) {
                                 try {
-                                    Map<Integer, Long> idxs = msg.updateIdxs();
+                                    Map<Integer, Long> cntrs = msg.updateCntrs();
 
                                     GridCacheAdapter<Object, Object> interCache =
                                         ctx.cache().internalCache(routine.handler().cacheName());
 
-                                    if (interCache != null && idxs != null && interCache.context() != null
+                                    if (interCache != null && cntrs != null && interCache.context() != null
                                         && !interCache.isLocal() && !CU.clientNode(ctx.grid().localNode())) {
                                         Map<Integer, Long> map = interCache.context().topology().updateCounters();
 
                                         for (Map.Entry<Integer, Long> e : map.entrySet()) {
-                                            Long cntr0 = idxs.get(e.getKey());
+                                            Long cntr0 = cntrs.get(e.getKey());
                                             Long cntr1 = e.getValue();
 
                                             if (cntr0 == null || cntr1 > cntr0)
-                                                idxs.put(e.getKey(), cntr1);
+                                                cntrs.put(e.getKey(), cntr1);
                                         }
                                     }
                                 }
                                 catch (Exception e) {
-                                    if (log.isDebugEnabled())
-                                        log.warning("Failed to load update counters.", e);
+                                    U.warn(log, "Failed to load update counters.", e);
                                 }
 
-                                routine.handler().updateIdx(msg.updateIdxs());
+                                routine.handler().updateCounters(msg.updateCntrs());
                             }
 
                             fut.onRemoteRegistered();
@@ -891,15 +890,14 @@ public class GridContinuousProcessor extends GridProcessorAdapter {
 
         try {
             if (ctx.cache() != null && ctx.cache().internalCache(hnd.cacheName()) != null) {
-                Map<Integer, Long> idx = ctx.cache().internalCache(hnd.cacheName())
+                Map<Integer, Long> cntrs = ctx.cache().internalCache(hnd.cacheName())
                     .context().topology().updateCounters();
 
-                req.addUpdateIdxs(idx);
+                req.addUpdateIdxs(cntrs);
             }
         }
         catch (Exception e) {
-            if (log.isDebugEnabled())
-                log.warning("Failed to load partition counters.", e);
+            U.warn(log, "Failed to load partition counters.");
         }
 
         if (err != null)

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/StartRoutineAckDiscoveryMessage.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/StartRoutineAckDiscoveryMessage.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/StartRoutineAckDiscoveryMessage.java
index 0b5cfaf..012c53d 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/StartRoutineAckDiscoveryMessage.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/StartRoutineAckDiscoveryMessage.java
@@ -36,18 +36,18 @@ public class StartRoutineAckDiscoveryMessage extends AbstractContinuousMessage {
     private final Map<UUID, IgniteCheckedException> errs;
 
     /** */
-    private final Map<Integer, Long> updateIdxs;
+    private final Map<Integer, Long> updateCntrs;
 
     /**
      * @param routineId Routine id.
      * @param errs Errs.
      */
     public StartRoutineAckDiscoveryMessage(UUID routineId, Map<UUID, IgniteCheckedException> errs,
-        Map<Integer, Long> idx) {
+        Map<Integer, Long> cntrs) {
         super(routineId);
 
         this.errs = new HashMap<>(errs);
-        this.updateIdxs = idx;
+        this.updateCntrs = cntrs;
     }
 
     /** {@inheritDoc} */
@@ -55,9 +55,11 @@ public class StartRoutineAckDiscoveryMessage extends AbstractContinuousMessage {
         return null;
     }
 
-    /** {@inheritDoc} */
-    public Map<Integer, Long> updateIdxs() {
-        return updateIdxs;
+    /**
+     * @return Update counters for partitions.
+     */
+    public Map<Integer, Long> updateCntrs() {
+        return updateCntrs;
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/StartRoutineDiscoveryMessage.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/GridCacheTestEntryEx.java b/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/GridCacheTestEntryEx.java
index 110b9a6..566fc53 100644
--- a/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/GridCacheTestEntryEx.java
+++ b/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/GridCacheTestEntryEx.java
@@ -480,7 +480,7 @@ public class GridCacheTestEntryEx extends GridMetadataAwareAdapter implements Gr
         UUID subjId,
         String taskName,
         @Nullable GridCacheVersion dhtVer,
-        @Nullable Long updateIdx)
+        @Nullable Long updateCntr)
         throws IgniteCheckedException, GridCacheEntryRemovedException {
         return new GridCacheUpdateTxResult(true, rawPut(val, ttl));
     }
@@ -532,7 +532,7 @@ public class GridCacheTestEntryEx extends GridMetadataAwareAdapter implements Gr
         UUID subjId,
         String taskName,
         @Nullable CacheObject prevVal,
-        @Nullable Long updateIdx) throws IgniteCheckedException,
+        @Nullable Long updateCntr) throws IgniteCheckedException,
         GridCacheEntryRemovedException {
         assert false;
 
@@ -555,7 +555,7 @@ public class GridCacheTestEntryEx extends GridMetadataAwareAdapter implements Gr
         UUID subjId,
         String taskName,
         @Nullable GridCacheVersion dhtVer,
-        @Nullable Long updatePartIdx
+        @Nullable Long updateCntr
         ) throws IgniteCheckedException, GridCacheEntryRemovedException {
         obsoleteVer = ver;
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryFailoverAbstractSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryFailoverAbstractSelfTest.java b/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryFailoverAbstractSelfTest.java
index dd4cf3e..a0b1878 100644
--- a/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryFailoverAbstractSelfTest.java
+++ b/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryFailoverAbstractSelfTest.java
@@ -61,7 +61,6 @@ import org.apache.ignite.cluster.ClusterTopologyException;
 import org.apache.ignite.configuration.CacheConfiguration;
 import org.apache.ignite.configuration.IgniteConfiguration;
 import org.apache.ignite.configuration.NearCacheConfiguration;
-import org.apache.ignite.internal.IgniteEx;
 import org.apache.ignite.internal.IgniteInternalFuture;
 import org.apache.ignite.internal.IgniteKernal;
 import org.apache.ignite.internal.managers.communication.GridIoMessage;
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheUpdateAtomicResult.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheUpdateAtomicResult.java
index 437f9f1..9df476e 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheUpdateAtomicResult.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheUpdateAtomicResult.java
@@ -18,11 +18,9 @@
 package org.apache.ignite.internal.processors.cache;
 
 import javax.cache.processor.EntryProcessor;
-import org.apache.ignite.internal.IgniteInternalFuture;
 import org.apache.ignite.internal.processors.cache.version.GridCacheVersion;
 import org.apache.ignite.internal.processors.cache.version.GridCacheVersionConflictContext;
 import org.apache.ignite.internal.util.tostring.GridToStringInclude;
-import org.apache.ignite.internal.util.typedef.CI1;
 import org.apache.ignite.internal.util.typedef.internal.S;
 import org.apache.ignite.lang.IgniteBiTuple;
 import org.jetbrains.annotations.Nullable;
@@ -60,7 +58,7 @@ public class GridCacheUpdateAtomicResult {
     private final boolean sndToDht;
 
     /** */
-    private final Long updateIdx;
+    private final Long updateCntr;
 
     /** Value computed by entry processor. */
     private IgniteBiTuple<Object, Exception> res;
@@ -77,7 +75,7 @@ public class GridCacheUpdateAtomicResult {
      * @param rmvVer Version for deferred delete.
      * @param conflictRes DR resolution result.
      * @param sndToDht Whether update should be propagated to DHT node.
      * @param updateIdx Partition update counter.
      */
     public GridCacheUpdateAtomicResult(boolean success,
         @Nullable CacheObject oldVal,
@@ -88,7 +86,7 @@ public class GridCacheUpdateAtomicResult {
         @Nullable GridCacheVersion rmvVer,
         @Nullable GridCacheVersionConflictContext<?, ?> conflictRes,
         boolean sndToDht,
-        long updateIdx) {
+        long updateCntr) {
         this.success = success;
         this.oldVal = oldVal;
         this.newVal = newVal;
@@ -98,7 +96,7 @@ public class GridCacheUpdateAtomicResult {
         this.rmvVer = rmvVer;
         this.conflictRes = conflictRes;
         this.sndToDht = sndToDht;
-        this.updateIdx = updateIdx;
+        this.updateCntr = updateCntr;
     }
 
     /**
@@ -139,8 +137,8 @@ public class GridCacheUpdateAtomicResult {
     /**
      * @return Partition update index.
      */
-    public Long updateIdx() {
-        return updateIdx;
+    public Long updateCounter() {
+        return updateCntr;
     }
 
     /**

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/GridCacheUpdateTxResult.java
----------------------------------------------------------------------
@@ -77,7 +75,7 @@ public class GridCacheUpdateAtomicResult {
      * @param conflictRes DR resolution result.
      * @param sndToDht Whether update should be propagated to DHT node.
-     * @param updateIdx Partition update counter.
+     * @param updateCntr Partition update counter.
      */
     public GridCacheUpdateAtomicResult(boolean success,
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/near/GridNearTxRemote.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/near/GridNearTxRemote.java
index 50cbf4b..3fb1382 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/near/GridNearTxRemote.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/distributed/near/GridNearTxRemote.java
@@ -230,9 +230,9 @@ public class GridNearTxRemote extends GridDistributedTxRemoteAdapter {
     }
 
     /**
      * @param idxs Partition indexes.
      */
-    @Override public void setPartitionUpdateIdx(long[] idxs) {
+    @Override public void setPartitionUpdateCounters(long[] cntrs) {
         // No-op.
     }
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryBatchAck.java
----------------------------------------------------------------------
@@ -230,9 +230,9 @@ public class GridNearTxRemote extends GridDistributedTxRemoteAdapter {
 
     /**
-     * @param idxs Partition indexes.
+     * @param cntrs Partition indexes.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryEntry.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryEntry.java
index 939f7a3..a3c53ff 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryEntry.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryEntry.java
@@ -86,8 +86,8 @@ public class CacheContinuousQueryEntry implements GridCacheDeployable, Message {
     /** Partition. */
     private int part;
 
-    /** Update index. */
-    private long updateIdx;
+    /** Update counter. */
+    private long updateCntr;
 
     /** Flags. */
     private byte flags;
@@ -113,7 +113,7 @@ public class CacheContinuousQueryEntry implements GridCacheDeployable, Message {
      * @param newVal New value.
      * @param oldVal Old value.
      * @param part Partition.
-     * @param updateIdx Update index.
+     * @param updateCntr Update partition counter.
      * @param topVer Topology version if applicable.
      */
     CacheContinuousQueryEntry(
@@ -123,7 +123,7 @@ public class CacheContinuousQueryEntry implements GridCacheDeployable, Message {
         @Nullable CacheObject newVal,
         @Nullable CacheObject oldVal,
         int part,
-        long updateIdx,
+        long updateCntr,
         @Nullable AffinityTopologyVersion topVer) {
         this.cacheId = cacheId;
         this.evtType = evtType;
@@ -131,7 +131,7 @@ public class CacheContinuousQueryEntry implements GridCacheDeployable, Message {
         this.newVal = newVal;
         this.oldVal = oldVal;
         this.part = part;
-        this.updateIdx = updateIdx;
+        this.updateCntr = updateCntr;
         this.topVer = topVer;
     }
 
@@ -164,10 +164,10 @@ public class CacheContinuousQueryEntry implements GridCacheDeployable, Message {
     }
 
     /**
-     * @return Update index.
+     * @return Update counter.
      */
-    long updateIndex() {
-        return updateIdx;
+    long updateCounter() {
+        return updateCntr;
     }
 
     /**
@@ -203,10 +203,10 @@ public class CacheContinuousQueryEntry implements GridCacheDeployable, Message {
     }
 
     /**
      * @param idxs Filtered indexes.
      */
-    void filteredEvents(GridLongList idxs) {
-        filteredEvts = idxs;
+    void filteredEvents(GridLongList cntrs) {
+        filteredEvts = cntrs;
     }
 
     /**
@@ -334,7 +334,7 @@ public class CacheContinuousQueryEntry implements GridCacheDeployable, Message {
                 writer.incrementState();
 
             case 6:
-                if (!writer.writeLong("updateIdx", updateIdx))
+                if (!writer.writeLong("updateCntr", updateCntr))
                     return false;
 
                 writer.incrementState();
@@ -423,7 +423,7 @@ public class CacheContinuousQueryEntry implements GridCacheDeployable, Message {
                 reader.incrementState();
 
             case 6:
-                updateIdx = reader.readLong("updateIdx");
+                updateCntr = reader.readLong("updateCntr");
 
                 if (!reader.isLastRead())
                     return false;

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryHandler.java
----------------------------------------------------------------------
@@ -203,10 +203,10 @@ public class CacheContinuousQueryEntry implements GridCacheDeployable, Message {
 
     /**
-     * @param idxs Filtered indexes.
+     * @param cntrs Filtered events.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryHandler.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryHandler.java
index a3ad872..18cb1fa 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryHandler.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryHandler.java
@@ -143,7 +143,7 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
     private transient int cacheId;
 
     /** */
-    private Map<Integer, Long> initUpdIdx;
+    private Map<Integer, Long> initUpdCntrs;
 
     /**
      * Required by {@link Externalizable}.
@@ -221,8 +221,8 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
     }
 
     /** {@inheritDoc} */
-    @Override public void updateIdx(Map<Integer, Long> idx) {
-        this.initUpdIdx = idx;
+    @Override public void updateCounters(Map<Integer, Long> cntrs) {
+        this.initUpdCntrs = cntrs;
     }
 
     /** {@inheritDoc} */
@@ -250,15 +250,15 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
 
         GridCacheContext<K, V> cctx = cacheContext(ctx);
 
-        if (!internal && cctx != null && initUpdIdx != null) {
+        if (!internal && cctx != null && initUpdCntrs != null) {
             Map<Integer, Long> map = cctx.topology().updateCounters();
 
             for (Map.Entry<Integer, Long> e : map.entrySet()) {
-                Long cntr0 = initUpdIdx.get(e.getKey());
+                Long cntr0 = initUpdCntrs.get(e.getKey());
                 Long cntr1 = e.getValue();
 
                 if (cntr0 == null || cntr1 > cntr0)
-                    initUpdIdx.put(e.getKey(), cntr1);
+                    initUpdCntrs.put(e.getKey(), cntr1);
             }
         }
 
@@ -402,15 +402,15 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
                     ((PlatformContinuousQueryFilter)rmtFilter).onQueryUnregister();
             }
 
-            @Override public void cleanupBackupQueue(Map<Integer, Long> updateIdxs) {
+            @Override public void cleanupBackupQueue(Map<Integer, Long> updateCntrs) {
                 Iterator<CacheContinuousQueryEntry> it = backupQueue.iterator();
 
                 while (it.hasNext()) {
                     CacheContinuousQueryEntry backupEntry = it.next();
 
-                    Long updateIdx = updateIdxs.get(backupEntry.partition());
+                    Long updateCntr = updateCntrs.get(backupEntry.partition());
 
-                    if (updateIdx != null && backupEntry.updateIndex() <= updateIdx)
+                    if (updateCntr != null && backupEntry.updateCounter() <= updateCntr)
                         it.remove();
                 }
             }
@@ -586,14 +586,14 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
 
         // Initial query entry or evicted entry.
         // This events should be fired immediately.
-        if (e.updateIndex() == -1)
+        if (e.updateCounter() == -1)
             return F.asList(e);
 
         PartitionRecovery rec = rcvs.get(e.partition());
 
         if (rec == null) {
             rec = new PartitionRecovery(ctx.log(getClass()), cacheContext(ctx),
-                initUpdIdx == null ? null : initUpdIdx.get(e.partition()));
+                initUpdCntrs == null ? null : initUpdCntrs.get(e.partition()));
 
             PartitionRecovery oldRec = rcvs.putIfAbsent(e.partition(), rec);
 
@@ -621,7 +621,7 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
 
         // Initial query entry.
         // This events should be fired immediately.
-        if (e.updateIndex() == -1)
+        if (e.updateCounter() == -1)
             return e;
 
         HoleBuffer buf = snds.get(e.partition());
@@ -663,14 +663,14 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
         /**
          * @param log Logger.
          * @param cctx Cache context.
          * @param initIdx Update counters.
          */
-        public PartitionRecovery(IgniteLogger log, GridCacheContext cctx, @Nullable Long initIdx) {
+        public PartitionRecovery(IgniteLogger log, GridCacheContext cctx, @Nullable Long initCntr) {
             this.log = log;
             this.cctx = cctx;
 
-            if (initIdx != null) {
-                this.lastFiredEvt = initIdx;
+            if (initCntr != null) {
+                this.lastFiredEvt = initCntr;
 
                 curTop = cctx.topology().topologyVersion();
             }
@@ -690,7 +690,7 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
             synchronized (pendingEvts) {
                 // Received first event.
                 if (curTop == AffinityTopologyVersion.NONE) {
-                    lastFiredEvt = entry.updateIndex();
+                    lastFiredEvt = entry.updateCounter();
 
                     curTop = entry.topologyVersion();
 
@@ -698,7 +698,7 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
                 }
 
                 if (curTop.compareTo(entry.topologyVersion()) < 0) {
-                    if (entry.updateIndex() == 1 && !entry.isBackup()) {
+                    if (entry.updateCounter() == 1 && !entry.isBackup()) {
                         entries = new ArrayList<>(pendingEvts.size());
 
                         for (CacheContinuousQueryEntry evt : pendingEvts.values()) {
@@ -710,7 +710,7 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
 
                         curTop = entry.topologyVersion();
 
-                        lastFiredEvt = entry.updateIndex();
+                        lastFiredEvt = entry.updateCounter();
 
                         entries.add(entry);
 
@@ -721,14 +721,14 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
                 }
 
                 // Check duplicate.
-                if (entry.updateIndex() > lastFiredEvt) {
-                    pendingEvts.put(entry.updateIndex(), entry);
+                if (entry.updateCounter() > lastFiredEvt) {
+                    pendingEvts.put(entry.updateCounter(), entry);
 
                     // Put filtered events.
                     if (entry.filteredEvents() != null) {
-                        for (long idx : entry.filteredEvents()) {
-                            if (idx > lastFiredEvt)
-                                pendingEvts.put(idx, HOLE);
+                        for (long cnrt : entry.filteredEvents()) {
+                            if (cnrt > lastFiredEvt)
+                                pendingEvts.put(cnrt, HOLE);
                         }
                     }
                 }
@@ -804,14 +804,14 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
             assert e != null;
 
             if (e.isFiltered()) {
-                if (lastFiredCntr.get() > e.updateIndex() || e.updateIndex() == 1)
+                if (lastFiredCntr.get() > e.updateCounter() || e.updateCounter() == 1)
                     return e;
                 else {
-                    buf.add(e.updateIndex());
+                    buf.add(e.updateCounter());
 
                     // Double check. If another thread sent a event with counter higher than this event.
-                    if (lastFiredCntr.get() > e.updateIndex() && buf.contains(e.updateIndex())) {
-                        buf.remove(e.updateIndex());
+                    if (lastFiredCntr.get() > e.updateCounter() && buf.contains(e.updateCounter())) {
+                        buf.remove(e.updateCounter());
 
                         return e;
                     }
@@ -820,12 +820,12 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
                 }
             }
             else {
-                long prevVal = setLastFiredCounter(e.updateIndex());
+                long prevVal = setLastFiredCounter(e.updateCounter());
 
                 if (prevVal == -1)
                     return e;
                 else {
-                    NavigableSet<Long> prevHoles = buf.subSet(prevVal, true, e.updateIndex(), true);
+                    NavigableSet<Long> prevHoles = buf.subSet(prevVal, true, e.updateCounter(), true);
 
                     GridLongList filteredEvts = new GridLongList(10);
 
@@ -834,9 +834,9 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
                     Iterator<Long> iter = prevHoles.iterator();
 
                     while (iter.hasNext()) {
-                        long idx = iter.next();
+                        long cntr = iter.next();
 
-                        filteredEvts.add(idx);
+                        filteredEvts.add(cntr);
 
                         iter.remove();
 
@@ -1013,7 +1013,7 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
 
         /** */
         @GridToStringInclude
-        private Map<Integer, Long> updateIdxs = new HashMap<>();
+        private Map<Integer, Long> updateCntrs = new HashMap<>();
 
         /** */
         @GridToStringInclude
@@ -1055,10 +1055,10 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
         private void addEntry(CacheContinuousQueryEntry e) {
             topVers.add(e.topologyVersion());
 
-            Long cntr0 = updateIdxs.get(e.partition());
+            Long cntr0 = updateCntrs.get(e.partition());
 
-            if (cntr0 == null || e.updateIndex() > cntr0)
-                updateIdxs.put(e.partition(), e.updateIndex());
+            if (cntr0 == null || e.updateCounter() > cntr0)
+                updateCntrs.put(e.partition(), e.updateCounter());
         }
 
         /**
@@ -1075,10 +1075,10 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
         private IgniteBiTuple<Map<Integer, Long>, Set<AffinityTopologyVersion>> acknowledgeData() {
             assert size > 0;
 
-            Map<Integer, Long> idxs = new HashMap<>(updateIdxs);
+            Map<Integer, Long> cntrs = new HashMap<>(updateCntrs);
 
             IgniteBiTuple<Map<Integer, Long>, Set<AffinityTopologyVersion>> res =
-                new IgniteBiTuple<>(idxs, topVers);
+                new IgniteBiTuple<>(cntrs, topVers);
 
             topVers = U.newHashSet(1);
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryListener.java
----------------------------------------------------------------------
@@ -663,14 +663,14 @@ class CacheContinuousQueryHandler<K, V> implements GridContinuousHandler {
          * @param log Logger.
          * @param cctx Cache context.
-         * @param initIdx Update counters.
+         * @param initCntr Update counters.
          */
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryListener.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryListener.java
index 4937ee7..4f345ed 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryListener.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryListener.java
@@ -48,9 +48,9 @@ interface CacheContinuousQueryListener<K, V> {
     /**
      * Cleans backup queue.
      *
      * @param updateIdxs Update indexes map.
      */
-    public void cleanupBackupQueue(Map<Integer, Long> updateIdxs);
+    public void cleanupBackupQueue(Map<Integer, Long> updateCntrs);
 
     /**
      * Flushes backup queue.

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/query/continuous/CacheContinuousQueryManager.java
----------------------------------------------------------------------
@@ -48,9 +48,9 @@ interface CacheContinuousQueryListener<K, V> {
      * Cleans backup queue.
      *
-     * @param updateIdxs Update indexes map.
+     * @param updateCntrs Update indexes map.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxRemoteEx.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxRemoteEx.java
index 845f4f0..63ed7f4 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxRemoteEx.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/cache/transactions/IgniteTxRemoteEx.java
@@ -45,7 +45,7 @@ public interface IgniteTxRemoteEx extends IgniteInternalTx {
     public boolean setWriteValue(IgniteTxEntry e);
 
     /**
      * @param idxs Partition update indexes.
      */
-    public void setPartitionUpdateIdx(long[] idxs);
+    public void setPartitionUpdateCounters(long[] cntrs);
 }

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/GridContinuousHandler.java
----------------------------------------------------------------------
@@ -45,7 +45,7 @@ public interface IgniteTxRemoteEx extends IgniteInternalTx {
 
     /**
-     * @param idxs Partition update indexes.
+     * @param cntrs Partition update indexes.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/GridContinuousHandler.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/GridContinuousHandler.java
index 648ed7b..d8698b3 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/GridContinuousHandler.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/GridContinuousHandler.java
@@ -148,7 +148,7 @@ public interface GridContinuousHandler extends Externalizable, Cloneable {
     public String cacheName();
 
     /**
      * @param idx Init state for partition indexies.
      */
-    public void updateIdx(Map<Integer, Long> idx);
+    public void updateCounters(Map<Integer, Long> cntrs);
 }
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/GridContinuousProcessor.java
----------------------------------------------------------------------
@@ -148,7 +148,7 @@ public interface GridContinuousHandler extends Externalizable, Cloneable {
 
     /**
-     * @param idx Init state for partition indexies.
+     * @param cntrs Init state for partition counters.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/StartRoutineDiscoveryMessage.java b/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/StartRoutineDiscoveryMessage.java
index ce818f0..434ed6d 100644
--- a/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/StartRoutineDiscoveryMessage.java
+++ b/modules/core/src/main/java/org/apache/ignite/internal/processors/continuous/StartRoutineDiscoveryMessage.java
@@ -38,7 +38,7 @@ public class StartRoutineDiscoveryMessage extends AbstractContinuousMessage {
     private final Map<UUID, IgniteCheckedException> errs = new HashMap<>();
 
     /** */
-    private Map<Integer, Long> updateIdxes;
+    private Map<Integer, Long> updateCntrs;
 
     /**
      * @param routineId Routine id.
@@ -66,18 +66,18 @@ public class StartRoutineDiscoveryMessage extends AbstractContinuousMessage {
     }
 
     /**
      * @param idx Update indexes.
      */
-    public void addUpdateIdxs(Map<Integer, Long> idx) {
-        if (updateIdxes == null)
-            updateIdxes = new HashMap<>();
+    public void addUpdateIdxs(Map<Integer, Long> cntrs) {
+        if (updateCntrs == null)
+            updateCntrs = new HashMap<>();
 
-        for (Map.Entry<Integer, Long> e : idx.entrySet()) {
-            Long cntr0 = updateIdxes.get(e.getKey());
+        for (Map.Entry<Integer, Long> e : cntrs.entrySet()) {
+            Long cntr0 = updateCntrs.get(e.getKey());
             Long cntr1 = e.getValue();
 
             if (cntr0 == null || cntr1 > cntr0)
-                updateIdxes.put(e.getKey(), cntr1);
+                updateCntrs.put(e.getKey(), cntr1);
         }
     }
 
@@ -95,7 +95,7 @@ public class StartRoutineDiscoveryMessage extends AbstractContinuousMessage {
 
     /** {@inheritDoc} */
     @Override public DiscoveryCustomMessage ackMessage() {
-        return new StartRoutineAckDiscoveryMessage(routineId, errs, updateIdxes);
+        return new StartRoutineAckDiscoveryMessage(routineId, errs, updateCntrs);
     }
 
     /** {@inheritDoc} */

http://git-wip-us.apache.org/repos/asf/ignite/blob/cd486cbe/modules/core/src/test/java/org/apache/ignite/internal/processors/cache/GridCacheTestEntryEx.java
----------------------------------------------------------------------
@@ -66,18 +66,18 @@ public class StartRoutineDiscoveryMessage extends AbstractContinuousMessage {
 
     /**
-     * @param idx Update indexes.
+     * @param cntrs Update counters.
      */